@@ -3,7 +3,7 @@
 /// @brief  Test the move constructor and move assignment operators
 ///         of the primesieve::iterator class.
 ///
-/// Copyright (C) 2018 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -37,17 +37,17 @@ int main()
   primesieve::iterator it2(std::move(it));
 
   // use 2nd iterator up to 1e9
-  for (; prime < 1000000000ull; prime = it2.next_prime())
+  for (; prime <= 1000000000ull; prime = it2.next_prime())
     sum += prime;
 
-  std::cout << "Sum of the primes below 10^9 = " << sum;
+  std::cout << "Sum of the primes <= 10^9: " << sum;
   check(sum == 24739512092254535ull);
 
   // test move assignment operator ///////////////////////////////////
 
   // moved from objects can be reused
   // but they need to be reset
-  it.skipto(0);
+  it.jump_to(0);
   prime = it.next_prime();
   sum = 0;
 
@@ -59,10 +59,10 @@ int main()
   it2 = std::move(it);
 
   // use 2nd iterator up to 1e9
-  for (; prime < 1000000000ull; prime = it2.next_prime())
+  for (; prime <= 1000000000ull; prime = it2.next_prime())
     sum += prime;
 
-  std::cout << "Sum of the primes below 10^9 = " << sum;
+  std::cout << "Sum of the primes <= 10^9: " << sum;
   check(sum == 24739512092254535ull);
 
   // test std::vector ////////////////////////////////////////////////
@@ -73,11 +73,11 @@ int main()
   std::cout << "1st prime < 1000 = " << prime;
   check(prime == 997);
 
-  it2.skipto(5);
+  it2.jump_to(5);
   vect.emplace_back(std::move(it2));
   prime = vect.back().next_prime();
-  std::cout << "1st prime > 5 = " << prime;
-  check(prime == 7);
+  std::cout << "1st prime >= 5 = " << prime;
+  check(prime == 5);
 
   return 0;
 }
